Rails.application.routes.draw do
  require 'sidekiq/web'

  devise_for :users

  namespace :auth do
    mount_devise_token_auth_for 'User', skip: [:omniauth_callbacks]
  end

  namespace :management do
    root 'welcome#index'

    resources :statistics do
      collection do
        get :users
        get :collections
        get :accesses
        get :downloads
      end
    end

    get 'highlights/new' => 'highlights#new', as: 'new_highlights'
    get 'highlights/delete' => 'highlights#delete', as: 'delete_highlights'
    get 'highlights/index' => 'highlights#index', as: 'index_highlights'
    resources :users

    resources :highlights

    resources :carousels

    mount Sidekiq::Web, at: '/sidekiq'

  end

  root 'welcome#index'

  resources :learning_objects do
    member do
      post :like
    end
  end

  resources :institutions
  resources :collections
  resources :subjects, only: [:index, :show]

  resources :users, only: [:show] do
    collection do
      get :me
    end
  end
  get 'users/:id', to: 'users#show', as: 'users_show'

  get '/faq' => 'welcome#faq'
  get '/contact' => 'welcome#contact', as: 'contact'
  get '/complaint' => 'welcome#complaint', as: 'complaint'
  get '/search' => 'search#index', as: 'search'
  get '/subject/:id' => 'welcome#subject', as:'subject_index'

end
