module OrientDb

  ##
  # This class represents an orient db migration
  #
  # The purpose of this class is to be an abstract class,
  # and extendend by concrete migrations
  class Migration

    def initialize(client)
      @client = client
    end

    protected

    ##
    # Create a orient db class in graph schema
    #
    # If +klass+ exists in current schema, nothing happens.
    #
    # A block can be passed with the created +klass+ object
    def create_class(klass, extends)
      unless @client.class_exists? klass
        @client.create_class(klass, :extends => extends) do |c|
          if block_given?
            yield c
          end
        end
      end
    end

    def drop_class(klass)
      if @client.class_exists? klass
        @client.drop_class(klass, :mode => :strict)
      end
    end

    def add_index(klass, properties, type, name=nil, engine=nil, metadata=nil)
      engine = engine.nil? ? "" : " ENGINE #{engine}"
      metadata = metadata.nil? ? "" : " METADATA #{metadata.to_s}"
      props = stringify(properties,", ")
      name = name.nil? ? "#{klass}."+stringify(properties,"_") : name;
      
      begin
        index = "CREATE INDEX #{name} ON #{klass} (#{props}) #{type}#{engine}#{metadata}"
        @client.command index
      rescue Orientdb4r::ServerError => e
        # If the index already exists OrientDB will give an error containing this message
        unless e.message.include? "Index with name #{name.downcase}"
          puts "Error at index creation"
          p e.message
          p e.backtrace
        end
      end
    end

    private
    def stringify(array, separator)
      str = ""
      array.each do |value|
        str += value.to_s+separator 
      end
      str[0..-(separator.size+1)]
    end

  end
end